---
title: 결제취소는 언제까지 가능한가요?
category: 자주 묻는 질문 (일반 문의) > 결제서비스 > 결제서비스
seo:
  title: 결제취소는 언제까지 가능한가요?
  description: >-
    결제취소가 가능한 기한 안내입니다. 결제하신 수단에 따라 다르며 기본적으로 원천사(카드사, 통신사 등)의기준을 따라 적용됩니다. 지금
    상세 정보를 확인해보세요.
  keywords:
    - 일반결제
tags:
  - 공통
  - 일반결제
pgCompanies:
  - 공통
searchTags:
  - 최대결제취소
  - 결제취소기간
  - 결제취소가능기간
  - 결제취소기한
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="" title="결제취소가 가능한 기한을 안내드립니다." />

- 결제취소는 결제하신 수단에 따라 다르며 기본적으로 **원천사(카드사, 통신사 등)의 기준**을 따라 적용됩니다.
- 일반적으로 **카드는 결제 이후 1년 이내,** 가상계좌,계좌이체는 기한 제한이 없이 취소가 가능하며, 휴대폰결제는 반드시 결제한 당월 내에만 취소가 가능합니다.

<Callout content="유의하셔야 할 점은 
1. 휴대폰결제는 하루 차이일지라도 다른 달일 경우 환불이 불가합니다. 
(ex 1월 31일 결제된 건을 2월 1일에 취소하려고 할 경우 취소불가) 
2. 또한 카드의 경우 카드사에 따라 취소기한이 상이할 수 있으므로, 이용하시는 카드사를 통해 확인이 필요합니다." title="유의사항" icon="❗" />
